=================================
``psyclone.psyir.nodes.schedule``
=================================

.. automodule:: psyclone.psyir.nodes.schedule

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.schedule


Classes
=======

- :py:class:`Schedule`:
  Stores schedule information for a sequence of statements (supplied


.. autoclass:: Schedule
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Schedule
      :parts: 1
